Task: Movie Dialog QA
======================
Description: Closed-domain QA dataset asking templated questions about movies, answerable from Wikipedia, similar to WikiMovies. From Dodge et al. '15. 

Link: https://arxiv.org/abs/1511.06931

Tags: #MovieDD-QA, #All, #QA, #MovieDD



Task: Movie Dialog QA Recommendations
======================================
Description: Dialogs discussing questions about movies as well as recommendations. From Dodge et al. '15. 

Link: https://arxiv.org/abs/1511.06931

Tags: #MovieDD-QARecs, #All, #Goal, #MovieDD



Task: Movie Dialog Recommendations
===================================
Description: Questions asking for movie recommendations. From Dodge et al. '15. 

Link: https://arxiv.org/abs/1511.06931

Tags: #MovieDD-Recs, #All, #QA, #MovieDD



Task: Movie Dialog Reddit
==========================
Description: Dialogs discussing Movies from Reddit (the Movies SubReddit). From Dodge et al. '15. 

Link: https://arxiv.org/abs/1511.06931

Tags: #MovieDD-Reddit, #All, #ChitChat, #MovieDD

